@@ -4,22 +4,22 @@
 #'
 #' @description Compact htsr sqlite data base
 #'
-#' @param db.sqlite Full name of the data base
+#' @param fsq Full name of the data base
 
 #' @return
 #' New data base or overwritten data base. Note that the created data base is empty.
 #'
 
-d_compact <- function(db.sqlite) {
+d_compact <- function(fsq) {
 
   # Creation
-  if(!file.exists(db.sqlite)== TRUE)
-    return (warning ("The base ",db.sqlite, " doesn't exist."))
-  d_backup(db.sqlite)
-  conn <- dbConnect(SQLite(), db.sqlite)
+  if(!file.exists(fsq)== TRUE)
+    return (warning ("The base ",fsq, " doesn't exist."))
+  d_backup(fsq)
+  conn <- dbConnect(SQLite(), fsq)
   dbExecute(conn, "VACUUM")
   dbDisconnect(conn)
-  message ("\nBase ",db.sqlite, " compacted.")
+  message ("\nBase ",fsq, " compacted.")
 }
 
 
