@@ -5,13 +5,13 @@
 #' @description Shiny application of the  functions \code{\link{h_timestep}} and \code{\link{h_month}}
 #'
 #'
-#' @param fhts File name of the Sqlite data base
+#' @param file File name of the Sqlite data base
 
 #' @return a shiny session
 #'
 #'
-hs_tstep <- function(fhts){
-  fhts <- fhts
-  save(fhts, file=system.file("extdata/fichier_fhts.RData",package="htsr"))
+hs_tstep <- function(file){
+  fil <- file
+  save(fil, file=system.file("extdata/fichier_fhts.RData",package="htsr"))
   runApp(system.file("extdata/app_tstep", package="htsr"))
 }
